
[![Documentation status](https://readthedocs.org/projects/ngs-toolkit/badge/?version=latest)](http://ngs-toolkit.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/ngs-toolkit.svg)](https://badge.fury.io/py/ngs-toolkit)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/30fcafc027e64b21bf9ddfe8d7f0ff3a)](https://app.codacy.com/app/afrendeiro/toolkit?utm_source=github.com&utm_medium=referral&utm_content=afrendeiro/toolkit&utm_campaign=Badge_Grade_Dashboard)
[![Build Status](https://travis-ci.org/afrendeiro/toolkit.svg?branch=master)](https://travis-ci.org/afrendeiro/toolkit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![Gitter](https://badges.gitter.im/ngs-toolkit/Lobby.svg)](https://gitter.im/ngs-toolkit/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![PEP compatible](http://pepkit.github.io/img/PEP-compatible-green.svg)](http://pepkit.github.io)

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://gitpod.io/#https://github.com/afrendeiro/toolkit)

# ngs-toolkit

This is my NGS analysis toolkit: ``ngs_toolkit``.

Head to the [documentation](http://ngs-toolkit.readthedocs.io/) to see how to install and use the toolkit, and have a look at the catalogue of available functions.

Install with:

```bash
pip install ngs-toolkit
```

You might need to add a ``--user`` flag to the above command.
